# Environment

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**name** | **str** |  | 
**cluster_id** | **str** |  | [optional] 
**cluster_status** | **str** |  | [optional] 
**config** | **object** |  | [optional] 
**type** | **str** |  | 
**terminate_after_idle_minutes** | **float** |  | [optional] [default to 120]
**idle_alarm_name** | **str** |  | [optional] 
**concurrency** | **float** |  | [optional] [default to 1]
**organization_id** | **str** |  | [optional] 
**model_jobs** | [**list[ModelJob]**](ModelJob.md) |  | [optional] 
**activity_marker** | **str** |  | [optional] 
**activities** | [**list[EnvironmentActivity]**](EnvironmentActivity.md) |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

